# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`logrotate`](#logrotate): Configure LogRotate global options  Use ``logrotate::rule`` for specific configuration options.

### Defined types

* [`logrotate::rule`](#logrotate--rule): Add a LogRotate Configuration  If options have a 'no' variant, then the no variant will be set if you set the primary value to false  The ``l

### Data types

* [`Logrotate::Periods`](#Logrotate--Periods): Allowed time intervals for logrotate
* [`Logrotate::Size`](#Logrotate--Size): Size of a log in bytes, kilobytes, megabytes or gigabytes

## Classes

### <a name="logrotate"></a>`logrotate`

Configure LogRotate global options

Use ``logrotate::rule`` for specific configuration options.

#### Parameters

The following parameters are available in the `logrotate` class:

* [`rotate_period`](#-logrotate--rotate_period)
* [`rotate`](#-logrotate--rotate)
* [`create`](#-logrotate--create)
* [`compress`](#-logrotate--compress)
* [`configdir`](#-logrotate--configdir)
* [`include_dirs`](#-logrotate--include_dirs)
* [`manage_wtmp`](#-logrotate--manage_wtmp)
* [`dateext`](#-logrotate--dateext)
* [`dateformat`](#-logrotate--dateformat)
* [`dateyesterday`](#-logrotate--dateyesterday)
* [`maxsize`](#-logrotate--maxsize)
* [`minsize`](#-logrotate--minsize)
* [`package_ensure`](#-logrotate--package_ensure)
* [`logger_service`](#-logrotate--logger_service)

##### <a name="-logrotate--rotate_period"></a>`rotate_period`

Data type: `Logrotate::Periods`

How often to rotate the logs

Default value: `'weekly'`

##### <a name="-logrotate--rotate"></a>`rotate`

Data type: `Integer[0]`

The number of times to rotate the logs before removing them from the
system

Default value: `4`

##### <a name="-logrotate--create"></a>`create`

Data type: `Boolean`

Create new log files if they do not exist

Default value: `true`

##### <a name="-logrotate--compress"></a>`compress`

Data type: `Boolean`

Compress the logs upon rotation

Default value: `true`

##### <a name="-logrotate--configdir"></a>`configdir`

Data type: `Stdlib::Absolutepath`

The primary directory for SIMP-managed configuration files.

Default value: `'/etc/logrotate.simp.d'`

##### <a name="-logrotate--include_dirs"></a>`include_dirs`

Data type: `Array[Stdlib::Absolutepath]`

Directories to include in your logrotate configuration

* ``$logrotate::configdir`` is always included and is listed first
* Be sure to include ``/etc/logrotate.d`` in this list if you
  override the default.

Default value: `[ '/etc/logrotate.d' ]`

##### <a name="-logrotate--manage_wtmp"></a>`manage_wtmp`

Data type: `Boolean`

Set to ``false`` if you do not want ``/var/log/wtmp`` to be managed by
logrotate

Default value: `true`

##### <a name="-logrotate--dateext"></a>`dateext`

Data type: `Boolean`

Use ``dateext`` as the suffix for rotated files

Default value: `true`

##### <a name="-logrotate--dateformat"></a>`dateformat`

Data type: `String[1]`

The format of the date to be appended

* Leaving as is allows for multiple rotations per day

Default value: `'-%Y%m%d.%s'`

##### <a name="-logrotate--dateyesterday"></a>`dateyesterday`

Data type: `Optional[Boolean]`

Say 'yesterday' instead of the date

Default value: `undef`

##### <a name="-logrotate--maxsize"></a>`maxsize`

Data type: `Optional[Logrotate::Size]`

The default maximum size of a logfile

Default value: `undef`

##### <a name="-logrotate--minsize"></a>`minsize`

Data type: `Optional[Logrotate::Size]`

The default minimum size of a logfile

* Overrides the ``maxsize`` setting

Default value: `undef`

##### <a name="-logrotate--package_ensure"></a>`package_ensure`

Data type: `String[1]`

The ensure status of packages to be installed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-logrotate--logger_service"></a>`logger_service`

Data type: `String[1]`

The service that controls system logging

* This is used by the ``logrotate::rule`` define to note the name of the
  service to be restarted if, and only if, the default lastaction is
  enabled.

Default value: `'rsyslog'`

## Defined types

### <a name="logrotate--rule"></a>`logrotate::rule`

Add a LogRotate Configuration

If options have a 'no' variant, then the no variant will be set if you set
the primary value to false

The ``logrotate(5)`` man page should be referenced for any undocumented
parameter.

* **See also**
  * logrotate(5)

#### Parameters

The following parameters are available in the `logrotate::rule` defined type:

* [`name`](#-logrotate--rule--name)
* [`log_files`](#-logrotate--rule--log_files)
* [`compress`](#-logrotate--rule--compress)
* [`compresscmd`](#-logrotate--rule--compresscmd)
* [`uncompresscmd`](#-logrotate--rule--uncompresscmd)
* [`compressext`](#-logrotate--rule--compressext)
* [`compressoptions`](#-logrotate--rule--compressoptions)
* [`copy`](#-logrotate--rule--copy)
* [`copytruncate`](#-logrotate--rule--copytruncate)
* [`create`](#-logrotate--rule--create)
* [`rotate_period`](#-logrotate--rule--rotate_period)
* [`dateext`](#-logrotate--rule--dateext)
* [`dateformat`](#-logrotate--rule--dateformat)
* [`dateyesterday`](#-logrotate--rule--dateyesterday)
* [`delaycompress`](#-logrotate--rule--delaycompress)
* [`extension`](#-logrotate--rule--extension)
* [`ifempty`](#-logrotate--rule--ifempty)
* [`ext_include`](#-logrotate--rule--ext_include)
* [`mail`](#-logrotate--rule--mail)
* [`maillast`](#-logrotate--rule--maillast)
* [`maxage`](#-logrotate--rule--maxage)
* [`maxsize`](#-logrotate--rule--maxsize)
* [`minsize`](#-logrotate--rule--minsize)
* [`missingok`](#-logrotate--rule--missingok)
* [`olddir`](#-logrotate--rule--olddir)
* [`postrotate`](#-logrotate--rule--postrotate)
* [`prerotate`](#-logrotate--rule--prerotate)
* [`firstaction`](#-logrotate--rule--firstaction)
* [`lastaction`](#-logrotate--rule--lastaction)
* [`lastaction_restart_logger`](#-logrotate--rule--lastaction_restart_logger)
* [`logger_service`](#-logrotate--rule--logger_service)
* [`rotate`](#-logrotate--rule--rotate)
* [`size`](#-logrotate--rule--size)
* [`sharedscripts`](#-logrotate--rule--sharedscripts)
* [`shred`](#-logrotate--rule--shred)
* [`shredcycles`](#-logrotate--rule--shredcycles)
* [`start`](#-logrotate--rule--start)
* [`su`](#-logrotate--rule--su)
* [`su_user`](#-logrotate--rule--su_user)
* [`su_group`](#-logrotate--rule--su_group)
* [`tabooext`](#-logrotate--rule--tabooext)

##### <a name="-logrotate--rule--name"></a>`name`

Data type: `String`

Directly translates to the name of the file

##### <a name="-logrotate--rule--log_files"></a>`log_files`

Data type: `Array[String[1]]`

The log file strings for all logs to be affected by this stanza

##### <a name="-logrotate--rule--compress"></a>`compress`

Data type: `Optional[Boolean]`

If undefined it defaults to the setting in logrotate.

Default value: `undef`

##### <a name="-logrotate--rule--compresscmd"></a>`compresscmd`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--uncompresscmd"></a>`uncompresscmd`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--compressext"></a>`compressext`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--compressoptions"></a>`compressoptions`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--copy"></a>`copy`

Data type: `Boolean`



Default value: `false`

##### <a name="-logrotate--rule--copytruncate"></a>`copytruncate`

Data type: `Boolean`



Default value: `false`

##### <a name="-logrotate--rule--create"></a>`create`

Data type: `Pattern['\d{4} .+ .+']`



Default value: `'0640 root root'`

##### <a name="-logrotate--rule--rotate_period"></a>`rotate_period`

Data type: `Optional[Logrotate::Periods]`



Default value: `undef`

##### <a name="-logrotate--rule--dateext"></a>`dateext`

Data type: `Optional[Boolean]`

If set to true log files will be rotated using a date extension.
If false nodateext is set and rotated logs use a number extension.
If undefined it defaults to the setting in logrotate

Default value: `undef`

##### <a name="-logrotate--rule--dateformat"></a>`dateformat`

Data type: `String[1]`



Default value: `'-%Y%m%d.%s'`

##### <a name="-logrotate--rule--dateyesterday"></a>`dateyesterday`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-logrotate--rule--delaycompress"></a>`delaycompress`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-logrotate--rule--extension"></a>`extension`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--ifempty"></a>`ifempty`

Data type: `Boolean`



Default value: `false`

##### <a name="-logrotate--rule--ext_include"></a>`ext_include`

Data type: `Optional[Array[String[1]]]`

Corresponds to the ``include`` logrotate configuration since it is a
reserved word in Puppet

Default value: `undef`

##### <a name="-logrotate--rule--mail"></a>`mail`

Data type: `Optional[Simplib::EmailAddress]`



Default value: `undef`

##### <a name="-logrotate--rule--maillast"></a>`maillast`

Data type: `Boolean`

If false, mailfirst will be set. Ignored if $mail is `false`

Default value: `true`

##### <a name="-logrotate--rule--maxage"></a>`maxage`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-logrotate--rule--maxsize"></a>`maxsize`

Data type: `Optional[Logrotate::Size]`



Default value: `undef`

##### <a name="-logrotate--rule--minsize"></a>`minsize`

Data type: `Optional[Logrotate::Size]`



Default value: `undef`

##### <a name="-logrotate--rule--missingok"></a>`missingok`

Data type: `Boolean`



Default value: `false`

##### <a name="-logrotate--rule--olddir"></a>`olddir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-logrotate--rule--postrotate"></a>`postrotate`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--prerotate"></a>`prerotate`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--firstaction"></a>`firstaction`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--lastaction"></a>`lastaction`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--lastaction_restart_logger"></a>`lastaction_restart_logger`

Data type: `Boolean`

Restart ``$logger_service`` as a logrotate ``lastaction``

* Has no effect if ``$lastaction`` is set

Default value: `false`

##### <a name="-logrotate--rule--logger_service"></a>`logger_service`

Data type: `Optional[String[1]]`

The name of the service which will be restarted as a logrotate ``lastaction``

* NOTE: This will default to ``rsyslog`` unless otherwise specified either
  in the call to the define or as ``logrotate::logger_service``

Default value: `simplib::lookup('logrotate::logger_service', {'default_value' => 'rsyslog'})`

##### <a name="-logrotate--rule--rotate"></a>`rotate`

Data type: `Optional[Integer[0]]`

The number of old log files to keep.
If undefined it defaults to the setting in logrotate

Default value: `undef`

##### <a name="-logrotate--rule--size"></a>`size`

Data type: `Optional[Logrotate::Size]`



Default value: `undef`

##### <a name="-logrotate--rule--sharedscripts"></a>`sharedscripts`

Data type: `Boolean`



Default value: `true`

##### <a name="-logrotate--rule--shred"></a>`shred`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-logrotate--rule--shredcycles"></a>`shredcycles`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-logrotate--rule--start"></a>`start`

Data type: `Integer[0]`



Default value: `1`

##### <a name="-logrotate--rule--su"></a>`su`

Data type: `Boolean`

Rotate logs as a different user and group. $su_user and $su_group are
required if this is set to true. Ignored on EL6.

Default value: `false`

##### <a name="-logrotate--rule--su_user"></a>`su_user`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--su_group"></a>`su_group`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-logrotate--rule--tabooext"></a>`tabooext`

Data type: `Optional[Array[String[1]]]`



Default value: `undef`

## Data types

### <a name="Logrotate--Periods"></a>`Logrotate::Periods`

Allowed time intervals for logrotate

Alias of `Enum['hourly', 'daily', 'weekly', 'monthly', 'yearly']`

### <a name="Logrotate--Size"></a>`Logrotate::Size`

Size of a log in bytes, kilobytes, megabytes or gigabytes

Alias of `Variant[Integer[1], Pattern[/^[0-9]+[kMG]?$/]]`

